summaryrefslogtreecommitdiffstats
path: root/korganizer/plugins/projectview/koprojectview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/plugins/projectview/koprojectview.cpp')
-rw-r--r--korganizer/plugins/projectview/koprojectview.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/korganizer/plugins/projectview/koprojectview.cpp b/korganizer/plugins/projectview/koprojectview.cpp
index 3c7678e1a..79b146b35 100644
--- a/korganizer/plugins/projectview/koprojectview.cpp
+++ b/korganizer/plugins/projectview/koprojectview.cpp
@@ -64,9 +64,9 @@ Todo *KOProjectViewItem::event()
}
-KOProjectView::KOProjectView(Calendar *calendar,TQWidget* tqparent,
+KOProjectView::KOProjectView(Calendar *calendar,TQWidget* parent,
const char* name) :
- KOrg::BaseView(calendar,tqparent,name)
+ KOrg::BaseView(calendar,parent,name)
{
TQBoxLayout *topLayout = new TQVBoxLayout(this);
@@ -183,7 +183,7 @@ void KOProjectView::updateView()
*/
// Put for each Event a KOProjectViewItem in the list view. Don't rely on a
// specific order of events. That means that we have to generate tqparent items
// recursively for proper hierarchical display of Todos.
mTodoMap.clear();
Todo::List::ConstIterator it;
@@ -216,7 +216,7 @@ TQMap<Todo *,KGanttItem *>::ConstIterator
}
}
-KGanttItem *KOProjectView::createTask(KGanttItem *tqparent,Todo *todo)
+KGanttItem *KOProjectView::createTask(KGanttItem *parent,Todo *todo)
{
TQDateTime startDt;
TQDateTime endDt;
@@ -237,7 +237,7 @@ KGanttItem *KOProjectView::createTask(KGanttItem *tqparent,Todo *todo)
endDt = todo->dtDue();
}
- KGanttItem *task = new KOProjectViewItem(todo,tqparent,todo->summary(),startDt,
+ KGanttItem *task = new KOProjectViewItem(todo,parent,todo->summary(),startDt,
endDt);
connect(task,TQT_SIGNAL(changed(KGanttItem*, KGanttItem::Change)),
TQT_SLOT(taskChanged(KGanttItem*,KGanttItem::Change)));
@@ -183,7 +183,7 @@ void KOProjectView::updateView()
*/
// Put for each Event a KOProjectViewItem in the list view. Don't rely on a
- // specific order of events. That means that we have to generate tqparent items
+ // specific order of events. That means that we have to generate parent items
// recursively for proper hierarchical display of Todos.
mTodoMap.clear();